// ***************************************************************************
// ***************************************************************************
// ***************************************************************************
// ***************************************************************************

#include <stdio.h>
#include "platform.h"
#include "xbasic_types.h"
#include "xstatus.h"
#include "xil_io.h"
#include "xparameters.h"
#include "xuartlite_l.h"

#define CF_BASEADDR   XPAR_AXI_AD9129_0_BASEADDR
#define UART_BASEADDR XPAR_RS232_UART_1_BASEADDR

// ***************************************************************************
// ***************************************************************************

extern char inbyte(void);
void xil_printf(const char *ctrl1, ...);

void delay_ms(u32 ms_count) {
  u32 count;
  for (count = 0; count < ((ms_count * 100000) + 1); count++) {
    asm("nop");
  }
}

u32 user_exit(void) {
  while (!XUartLite_IsReceiveEmpty(UART_BASEADDR)) {
    if (XUartLite_RecvByte(UART_BASEADDR) == 'q') {
      return(1);
    }
  }
  return(0);
}

// clocks must be in mhz

u32 ad9129_dds_count(u32 sin_clk, u32 dac_clk) {
  if (sin_clk > (dac_clk/2)) {
    xil_printf("sin(%d) over NS rate(%d)\n\r", sin_clk, dac_clk);
  }
  xil_printf("setting dds frequency at %d MHz.\n\r", sin_clk);
  return((65536 * sin_clk)/dac_clk);
}

// ***************************************************************************
// ***************************************************************************

int main() {

  init_platform();

  // after mu locked, program the dds (so that it's serdes is out of reset).

  Xil_Out32((CF_BASEADDR + 0x04), 0x00000);
  Xil_Out32((CF_BASEADDR + 0x04), (0x10001 | ad9129_dds_count(300, 2800)));

  xil_printf("done.\n\r");
  cleanup_platform();

  return(0);
}

// ***************************************************************************
// ***************************************************************************
